@@ -25,6 +25,7 @@ type RefresherConfig struct {
 
 type GuiConfig struct {
 	AuthorColors             map[string]string  `yaml:"authorColors"`
+	BranchColors             map[string]string  `yaml:"branchColors"`
 	ScrollHeight             int                `yaml:"scrollHeight"`
 	ScrollPastBottom         bool               `yaml:"scrollPastBottom"`
 	MouseEvents              bool               `yaml:"mouseEvents"`
@@ -247,6 +248,7 @@ type KeybindingCommitsConfig struct {
 	CopyCommitMessageToClipboard string `yaml:"copyCommitMessageToClipboard"`
 	OpenLogMenu                  string `yaml:"openLogMenu"`
 	OpenInBrowser                string `yaml:"openInBrowser"`
+	ViewBisectOptions            string `yaml:"viewBisectOptions"`
 }
 
 type KeybindingStashConfig struct {
@@ -293,6 +295,7 @@ type CustomCommand struct {
 	Prompts     []CustomCommandPrompt `yaml:"prompts"`
 	LoadingText string                `yaml:"loadingText"`
 	Description string                `yaml:"description"`
+	Stream      bool                  `yaml:"stream"`
 }
 
 type CustomCommandPrompt struct {
@@ -325,7 +328,7 @@ func GetDefaultConfig() *UserConfig {
 			ScrollPastBottom:       true,
 			MouseEvents:            true,
 			SkipUnstageLineWarning: false,
-			SkipStashWarning:       true,
+			SkipStashWarning:       false,
 			SidePanelWidth:         0.3333,
 			ExpandFocusedSidePanel: false,
 			MainPanelSplitMode:     "flexible",
@@ -510,6 +513,7 @@ func GetDefaultConfig() *UserConfig {
 				CopyCommitMessageToClipboard: "<c-y>",
 				OpenLogMenu:                  "<c-l>",
 				OpenInBrowser:                "o",
+				ViewBisectOptions:            "b",
 			},
 			Stash: KeybindingStashConfig{
 				PopStash: "g",
