@@ -8,8 +8,10 @@ import (
 	"github.com/jesseduffield/lazygit/pkg/commands/git_commands"
 	"github.com/jesseduffield/lazygit/pkg/commands/loaders"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
+	"github.com/jesseduffield/lazygit/pkg/commands/types/enums"
 	"github.com/jesseduffield/lazygit/pkg/config"
 	"github.com/jesseduffield/lazygit/pkg/gui/filetree"
+	"github.com/jesseduffield/lazygit/pkg/gui/mergeconflicts"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 )
 
@@ -21,7 +23,7 @@ func (gui *Gui) getSelectedFileNode() *filetree.FileNode {
 		return nil
 	}
 
-	return gui.State.FileManager.GetItemAtIndex(selectedLine)
+	return gui.State.FileTreeViewModel.GetItemAtIndex(selectedLine)
 }
 
 func (gui *Gui) getSelectedFile() *models.File {
@@ -54,9 +56,17 @@ func (gui *Gui) filesRenderToMain() error {
 	}
 
 	if node.File != nil && node.File.HasInlineMergeConflicts {
-		return gui.renderConflictsFromFilesPanel()
+		ok, err := gui.setConflictsAndRenderWithLock(node.GetPath(), false)
+		if err != nil {
+			return err
+		}
+		if ok {
+			return nil
+		}
 	}
 
+	gui.resetMergeStateWithLock()
+
 	cmdObj := gui.Git.WorkingTree.WorktreeFileDiffCmdObj(node, false, !node.GetHasUnstagedChanges() && node.GetHasStagedChanges(), gui.State.IgnoreWhitespaceInDiffView)
 
 	refreshOpts := refreshMainOpts{main: &viewUpdateOpts{
@@ -88,11 +98,16 @@ func (gui *Gui) refreshFilesAndSubmodules() error {
 		gui.Mutexes.RefreshingFilesMutex.Unlock()
 	}()
 
-	selectedPath := gui.getSelectedPath()
+	prevSelectedPath := gui.getSelectedPath()
 
 	if err := gui.refreshStateSubmoduleConfigs(); err != nil {
 		return err
 	}
+
+	if err := gui.refreshMergeState(); err != nil {
+		return err
+	}
+
 	if err := gui.refreshStateFiles(); err != nil {
 		return err
 	}
@@ -109,9 +124,9 @@ func (gui *Gui) refreshFilesAndSubmodules() error {
 			}
 		}
 
-		if gui.currentContext().GetKey() == FILES_CONTEXT_KEY || (gui.g.CurrentView() == gui.Views.Main && ContextKey(gui.g.CurrentView().Context) == MAIN_MERGING_CONTEXT_KEY) {
-			newSelectedPath := gui.getSelectedPath()
-			alreadySelected := selectedPath != "" && newSelectedPath == selectedPath
+		if gui.currentContext().GetKey() == FILES_CONTEXT_KEY {
+			currentSelectedPath := gui.getSelectedPath()
+			alreadySelected := prevSelectedPath != "" && currentSelectedPath == prevSelectedPath
 			if !alreadySelected {
 				gui.takeOverMergeConflictScrolling()
 			}
@@ -129,7 +144,7 @@ func (gui *Gui) refreshFilesAndSubmodules() error {
 // specific functions
 
 func (gui *Gui) stagedFiles() []*models.File {
-	files := gui.State.FileManager.GetAllFiles()
+	files := gui.State.FileTreeViewModel.GetAllFiles()
 	result := make([]*models.File, 0)
 	for _, file := range files {
 		if file.HasStagedChanges {
@@ -140,7 +155,7 @@ func (gui *Gui) stagedFiles() []*models.File {
 }
 
 func (gui *Gui) trackedFiles() []*models.File {
-	files := gui.State.FileManager.GetAllFiles()
+	files := gui.State.FileTreeViewModel.GetAllFiles()
 	result := make([]*models.File, 0, len(files))
 	for _, file := range files {
 		if file.Tracked {
@@ -150,15 +165,6 @@ func (gui *Gui) trackedFiles() []*models.File {
 	return result
 }
 
-func (gui *Gui) stageSelectedFile() error {
-	file := gui.getSelectedFile()
-	if file == nil {
-		return nil
-	}
-
-	return gui.Git.WorkingTree.StageFile(file.Name)
-}
-
 func (gui *Gui) handleEnterFile() error {
 	return gui.enterFile(OnFocusOpts{ClickedViewName: "", ClickedViewLineIdx: -1})
 }
@@ -244,7 +250,7 @@ func (gui *Gui) handleFilePress() error {
 }
 
 func (gui *Gui) allFilesStaged() bool {
-	for _, file := range gui.State.FileManager.GetAllFiles() {
+	for _, file := range gui.State.FileTreeViewModel.GetAllFiles() {
 		if file.HasUnstagedChanges {
 			return false
 		}
@@ -378,7 +384,7 @@ func (gui *Gui) handleCommitPress() error {
 		return gui.surfaceError(err)
 	}
 
-	if gui.State.FileManager.GetItemsLength() == 0 {
+	if gui.State.FileTreeViewModel.GetItemsLength() == 0 {
 		return gui.createErrorPanel(gui.Tr.NoFilesStagedTitle)
 	}
 
@@ -433,7 +439,7 @@ func (gui *Gui) promptToStageAllAndRetry(retry func() error) error {
 }
 
 func (gui *Gui) handleAmendCommitPress() error {
-	if gui.State.FileManager.GetItemsLength() == 0 {
+	if gui.State.FileTreeViewModel.GetItemsLength() == 0 {
 		return gui.createErrorPanel(gui.Tr.NoFilesStagedTitle)
 	}
 
@@ -459,7 +465,7 @@ func (gui *Gui) handleAmendCommitPress() error {
 // handleCommitEditorPress - handle when the user wants to commit changes via
 // their editor rather than via the popup panel
 func (gui *Gui) handleCommitEditorPress() error {
-	if gui.State.FileManager.GetItemsLength() == 0 {
+	if gui.State.FileTreeViewModel.GetItemsLength() == 0 {
 		return gui.createErrorPanel(gui.Tr.NoFilesStagedTitle)
 	}
 
@@ -498,9 +504,9 @@ func (gui *Gui) handleStatusFilterPressed() error {
 	return gui.createMenu(gui.Tr.FilteringMenuTitle, menuItems, createMenuOptions{showCancel: true})
 }
 
-func (gui *Gui) setStatusFiltering(filter filetree.FileManagerDisplayFilter) error {
+func (gui *Gui) setStatusFiltering(filter filetree.FileTreeDisplayFilter) error {
 	state := gui.State
-	state.FileManager.SetDisplayFilter(filter)
+	state.FileTreeViewModel.SetFilter(filter)
 	return gui.handleRefreshFiles()
 }
 
@@ -555,31 +561,85 @@ func (gui *Gui) refreshStateFiles() error {
 
 	selectedNode := gui.getSelectedFileNode()
 
-	prevNodes := gui.State.FileManager.GetAllItems()
+	prevNodes := gui.State.FileTreeViewModel.GetAllItems()
 	prevSelectedLineIdx := gui.State.Panels.Files.SelectedLineIdx
 
+	// If git thinks any of our files have inline merge conflicts, but they actually don't,
+	// we stage them.
+	// Note that if files with merge conflicts have both arisen and have been resolved
+	// between refreshes, we won't stage them here. This is super unlikely though,
+	// and this approach spares us from having to call `git status` twice in a row.
+	// Although this also means that at startup we won't be staging anything until
+	// we call git status again.
+	pathsToStage := []string{}
+	prevConflictFileCount := 0
+	for _, file := range state.FileTreeViewModel.GetAllFiles() {
+		if file.HasMergeConflicts {
+			prevConflictFileCount++
+		}
+		if file.HasInlineMergeConflicts {
+			hasConflicts, err := mergeconflicts.FileHasConflictMarkers(file.Name)
+			if err != nil {
+				gui.Log.Error(err)
+			} else if !hasConflicts {
+				pathsToStage = append(pathsToStage, file.Name)
+			}
+		}
+	}
+
+	if len(pathsToStage) > 0 {
+		gui.logAction(gui.Tr.Actions.StageResolvedFiles)
+		if err := gui.Git.WorkingTree.StageFiles(pathsToStage); err != nil {
+			return gui.surfaceError(err)
+		}
+	}
+
 	files := gui.Git.Loaders.Files.
 		GetStatusFiles(loaders.GetStatusFileOptions{})
 
-	// for when you stage the old file of a rename and the new file is in a collapsed dir
-	state.FileManager.RWMutex.Lock()
+	conflictFileCount := 0
 	for _, file := range files {
-		if selectedNode != nil && selectedNode.Path != "" && file.PreviousName == selectedNode.Path {
-			state.FileManager.ExpandToPath(file.Name)
+		if file.HasMergeConflicts {
+			conflictFileCount++
 		}
 	}
 
-	state.FileManager.SetFiles(files)
-	state.FileManager.RWMutex.Unlock()
+	if gui.Git.Status.WorkingTreeState() != enums.REBASE_MODE_NONE && conflictFileCount == 0 && prevConflictFileCount > 0 {
+		gui.OnUIThread(func() error { return gui.promptToContinueRebase() })
+	}
+
+	// for when you stage the old file of a rename and the new file is in a collapsed dir
+	state.FileTreeViewModel.RWMutex.Lock()
+	for _, file := range files {
+		if selectedNode != nil && selectedNode.Path != "" && file.PreviousName == selectedNode.Path {
+			state.FileTreeViewModel.ExpandToPath(file.Name)
+		}
+	}
+
+	// only taking over the filter if it hasn't already been set by the user.
+	// Though this does make it impossible for the user to actually say they want to display all if
+	// conflicts are currently being shown. Hmm. Worth it I reckon. If we need to add some
+	// extra state here to see if the user's set the filter themselves we can do that, but
+	// I'd prefer to maintain as little state as possible.
+	if conflictFileCount > 0 {
+		if state.FileTreeViewModel.GetFilter() == filetree.DisplayAll {
+			state.FileTreeViewModel.SetFilter(filetree.DisplayConflicted)
+		}
+	} else if state.FileTreeViewModel.GetFilter() == filetree.DisplayConflicted {
+		state.FileTreeViewModel.SetFilter(filetree.DisplayAll)
+	}
+
+	state.FileTreeViewModel.SetFiles(files)
+	state.FileTreeViewModel.RWMutex.Unlock()
 
 	if err := gui.fileWatcher.addFilesToFileWatcher(files); err != nil {
 		return err
 	}
 
 	if selectedNode != nil {
-		newIdx := gui.findNewSelectedIdx(prevNodes[prevSelectedLineIdx:], state.FileManager.GetAllItems())
+		newIdx := gui.findNewSelectedIdx(prevNodes[prevSelectedLineIdx:], state.FileTreeViewModel.GetAllItems())
 		if newIdx != -1 && newIdx != prevSelectedLineIdx {
-			newNode := state.FileManager.GetItemAtIndex(newIdx)
+			newNode := state.FileTreeViewModel.GetItemAtIndex(newIdx)
 			// when not in tree mode, we show merge conflict files at the top, so you
 			// can work through them one by one without having to sift through a large
 			// set of files. If you have just fixed the merge conflicts of a file, we
@@ -588,7 +648,7 @@ func (gui *Gui) refreshStateFiles() error {
 			// conflicts: the user in this case would rather work on the next file
 			// with merge conflicts, which will have moved up to fill the gap left by
 			// the last file, meaning the cursor doesn't need to move at all.
-			leaveCursor := !state.FileManager.InTreeMode() && newNode != nil &&
+			leaveCursor := !state.FileTreeViewModel.InTreeMode() && newNode != nil &&
 				selectedNode.File != nil && selectedNode.File.HasMergeConflicts &&
 				newNode.File != nil && !newNode.File.HasMergeConflicts
 
@@ -598,10 +658,23 @@ func (gui *Gui) refreshStateFiles() error {
 		}
 	}
 
-	gui.refreshSelectedLine(state.Panels.Files, state.FileManager.GetItemsLength())
+	gui.refreshSelectedLine(state.Panels.Files, state.FileTreeViewModel.GetItemsLength())
 	return nil
 }
 
+// promptToContinueRebase asks the user if they want to continue the rebase/merge that's in progress
+func (gui *Gui) promptToContinueRebase() error {
+	gui.takeOverMergeConflictScrolling()
+
+	return gui.ask(askOpts{
+		title:  "continue",
+		prompt: gui.Tr.ConflictsResolved,
+		handleConfirm: func() error {
+			return gui.genericMergeCommand(REBASE_OPTION_CONTINUE)
+		},
+	})
+}
+
 // Let's try to find our file again and move the cursor to that.
 // If we can't find our file, it was probably just removed by the user. In that
 // case, we go looking for where the next file has been moved to. Given that the
@@ -859,6 +932,18 @@ func (gui *Gui) switchToMerge() error {
 		return nil
 	}
 
+	gui.takeOverMergeConflictScrolling()
+
+	if gui.State.Panels.Merging.GetPath() != file.Name {
+		hasConflicts, err := gui.setMergeStateWithLock(file.Name)
+		if err != nil {
+			return err
+		}
+		if !hasConflicts {
+			return nil
+		}
+	}
+
 	return gui.pushContext(gui.State.Contexts.Merging)
 }
 
@@ -870,15 +955,6 @@ func (gui *Gui) openFile(filename string) error {
 	return nil
 }
 
-func (gui *Gui) anyFilesWithMergeConflicts() bool {
-	for _, file := range gui.State.FileManager.GetAllFiles() {
-		if file.HasMergeConflicts {
-			return true
-		}
-	}
-	return false
-}
-
 func (gui *Gui) handleCustomCommand() error {
 	return gui.prompt(promptOpts{
 		title:               gui.Tr.CustomCommand,
@@ -939,7 +1015,7 @@ func (gui *Gui) handleToggleDirCollapsed() error {
 		return nil
 	}
 
-	gui.State.FileManager.ToggleCollapsed(node.GetPath())
+	gui.State.FileTreeViewModel.ToggleCollapsed(node.GetPath())
 
 	if err := gui.postRefreshUpdate(gui.State.Contexts.Files); err != nil {
 		gui.Log.Error(err)
@@ -952,12 +1028,12 @@ func (gui *Gui) handleToggleFileTreeView() error {
 	// get path of currently selected file
 	path := gui.getSelectedPath()
 
-	gui.State.FileManager.ToggleShowTree()
+	gui.State.FileTreeViewModel.ToggleShowTree()
 
 	// find that same node in the new format and move the cursor to it
 	if path != "" {
-		gui.State.FileManager.ExpandToPath(path)
-		index, found := gui.State.FileManager.GetIndexForPath(path)
+		gui.State.FileTreeViewModel.ExpandToPath(path)
+		index, found := gui.State.FileTreeViewModel.GetIndexForPath(path)
 		if found {
 			gui.filesListContext().GetPanelState().SetSelectedLineIdx(index)
 		}
