@@ -96,7 +96,7 @@ func (gui *Gui) handleResetSubmodule(submodule *models.SubmoduleConfig) error {
 }
 
 func (gui *Gui) fileForSubmodule(submodule *models.SubmoduleConfig) *models.File {
-	for _, file := range gui.State.FileManager.GetAllFiles() {
+	for _, file := range gui.State.FileTreeViewModel.GetAllFiles() {
 		if file.IsSubmodule([]*models.SubmoduleConfig{submodule}) {
 			return file
 		}
@@ -193,25 +193,6 @@ func (gui *Gui) forSubmodule(callback func(*models.SubmoduleConfig) error) func(
 	}
 }
 
-func (gui *Gui) handleResetRemoveSubmodule(submodule *models.SubmoduleConfig) error {
-	menuItems := []*menuItem{
-		{
-			displayString: gui.Tr.LcSubmoduleStashAndReset,
-			onPress: func() error {
-				return gui.resetSubmodule(submodule)
-			},
-		},
-		{
-			displayString: gui.Tr.LcRemoveSubmodule,
-			onPress: func() error {
-				return gui.removeSubmodule(submodule)
-			},
-		},
-	}
-
-	return gui.createMenu(submodule.Name, menuItems, createMenuOptions{showCancel: true})
-}
-
 func (gui *Gui) handleBulkSubmoduleActionsMenu() error {
 	menuItems := []*menuItem{
 		{
