@@ -355,12 +355,12 @@ func dutchTranslationSet() TranslationSet {
 		LcCreateNewBranchFromCommit:         "creëer nieuwe branch van commit",
 		LcCopySubmoduleNameToClipboard:      "kopieer submodule naam naar klembord",
 		LcEnterSubmodule:                    "enter submodule",
-		LcViewResetAndRemoveOptions:         "bekijk reset en verwijder submodule opties",
 		LcAddSubmodule:                      "voeg nieuwe submodule toe",
 		LcInitSubmodule:                     "initialiseer submodule",
 		LcViewBulkSubmoduleOptions:          "bekijk bulk submodule opties",
 		LcViewStashFiles:                    "bekijk bestanden van stash entry",
 		CreatePullRequestOptions:            "Bekijk opties voor pull-aanvraag",
 		LcCreatePullRequestOptions:          "bekijk opties voor pull-aanvraag",
+		ConfirmRevertCommit:                 "Weet u zeker dat u {{.selectedCommit}} ongedaan wilt maken?",
 	}
 }
