@@ -398,7 +398,6 @@ type TranslationSet struct {
 	LcEditSubmoduleUrl                  string
 	LcInitializingSubmoduleStatus       string
 	LcInitSubmodule                     string
-	LcViewResetAndRemoveOptions         string
 	LcSubmoduleUpdate                   string
 	LcUpdatingSubmoduleStatus           string
 	LcBulkInitSubmodules                string
@@ -453,7 +452,25 @@ type TranslationSet struct {
 	SortCommits                         string
 	CantChangeContextSizeError          string
 	LcOpenCommitInBrowser               string
+	LcViewBisectOptions                 string
+	ConfirmRevertCommit                 string
 	Actions                             Actions
+	Bisect                              Bisect
+}
+
+type Bisect struct {
+	MarkStart                   string
+	MarkSkipCurrent             string
+	MarkSkipSelected            string
+	ResetTitle                  string
+	ResetPrompt                 string
+	ResetOption                 string
+	BisectMenuTitle             string
+	Mark                        string
+	Skip                        string
+	CompleteTitle               string
+	CompletePrompt              string
+	CompletePromptIndeterminate string
 }
 
 type Actions struct {
@@ -489,6 +506,7 @@ type Actions struct {
 	DiscardAllChangesInFile           string
 	DiscardAllUnstagedChangesInFile   string
 	StageFile                         string
+	StageResolvedFiles                string
 	UnstageFile                       string
 	UnstageAllFiles                   string
 	StageAllFiles                     string
@@ -541,6 +559,10 @@ type Actions struct {
 	OpenMergeTool                     string
 	OpenCommitInBrowser               string
 	OpenPullRequest                   string
+	StartBisect                       string
+	ResetBisect                       string
+	BisectSkip                        string
+	BisectMark                        string
 }
 
 const englishIntroPopupMessage = `
@@ -951,7 +973,6 @@ func EnglishTranslationSet() TranslationSet {
 		LcEditSubmoduleUrl:                  "update submodule URL",
 		LcInitializingSubmoduleStatus:       "initializing submodule",
 		LcInitSubmodule:                     "initialize submodule",
-		LcViewResetAndRemoveOptions:         "view reset and remove submodule options",
 		LcSubmoduleUpdate:                   "update submodule",
 		LcUpdatingSubmoduleStatus:           "updating submodule",
 		LcBulkInitSubmodules:                "bulk init submodules",
@@ -1005,6 +1026,8 @@ func EnglishTranslationSet() TranslationSet {
 		SortCommits:                         "commit sort order",
 		CantChangeContextSizeError:          "Cannot change context while in patch building mode because we were too lazy to support it when releasing the feature. If you really want it, please let us know!",
 		LcOpenCommitInBrowser:               "open commit in browser",
+		LcViewBisectOptions:                 "view bisect options",
+		ConfirmRevertCommit:                 "Are you sure you want to revert {{.selectedCommit}}?",
 		Actions: Actions{
 			// TODO: combine this with the original keybinding descriptions (those are all in lowercase atm)
 			CheckoutCommit:                    "Checkout commit",
@@ -1040,6 +1063,7 @@ func EnglishTranslationSet() TranslationSet {
 			DiscardAllChangesInFile:           "Discard all changes in file",
 			DiscardAllUnstagedChangesInFile:   "Discard all unstaged changes in file",
 			StageFile:                         "Stage file",
+			StageResolvedFiles:                "Stage files whose merge conflicts were resolved",
 			UnstageFile:                       "Unstage file",
 			UnstageAllFiles:                   "Unstage all files",
 			StageAllFiles:                     "Stage all files",
@@ -1091,6 +1115,22 @@ func EnglishTranslationSet() TranslationSet {
 			OpenMergeTool:                     "Open merge tool",
 			OpenCommitInBrowser:               "Open commit in browser",
 			OpenPullRequest:                   "Open pull request in browser",
+			StartBisect:                       "Start bisect",
+			ResetBisect:                       "Reset bisect",
+			BisectSkip:                        "Bisect skip",
+			BisectMark:                        "Bisect mark",
+		},
+		Bisect: Bisect{
+			Mark:                        "mark %s as %s",
+			MarkStart:                   "mark %s as %s (start bisect)",
+			Skip:                        "skip %s",
+			ResetTitle:                  "Reset 'git bisect'",
+			ResetPrompt:                 "Are you sure you want to reset 'git bisect'?",
+			ResetOption:                 "reset bisect",
+			BisectMenuTitle:             "Bisect",
+			CompleteTitle:               "Bisect complete",
+			CompletePrompt:              "Bisect complete! The following commit introduced the change:\n\n%s\n\nDo you want to reset 'git bisect' now?",
+			CompletePromptIndeterminate: "Bisect complete! Some commits were skipped, so any of the following commits may have introduced the change:\n\n%s\n\nDo you want to reset 'git bisect' now?",
 		},
 	}
 }
